aboutsummaryrefslogtreecommitdiff
path: root/api/routes/receiveZChain
diff options
context:
space:
mode:
Diffstat (limited to 'api/routes/receiveZChain')
-rw-r--r--api/routes/receiveZChain/index.js10
1 files changed, 5 insertions, 5 deletions
diff --git a/api/routes/receiveZChain/index.js b/api/routes/receiveZChain/index.js
index 6915842..a955b79 100644
--- a/api/routes/receiveZChain/index.js
+++ b/api/routes/receiveZChain/index.js
@@ -3,7 +3,7 @@
* of the application that run the test.
*
* Returns:
* - errno on failure
* - on success we process with addNSEntriesToFile()
*
*/
@@ -15,7 +15,7 @@ function continuethingsNS(validitycode,sh,res,gotit){
};
addNSEntriesToFile(entry,res);
} else {
- res.send({errno:"Invalid data"});
+ res.send({error:"Invalid data"});
}
}
/*
@@ -27,7 +27,7 @@ function continuethingsNS(validitycode,sh,res,gotit){
* 3. Matches regular expression /k51qzi5uqu5d[A-Za-z0-9]{50}/
*
* Returns:
* - errno on failure
* - on success the string is processed for further validation to the
* function getNSvalidity()
*
@@ -40,9 +40,9 @@ module.exports = (req, res) => {
if (regex.test(req.body.zchain)){ // && regex.test(req.body.block_signature)){
getNSvalidity(req.body.zchain,res);
} else {
- res.send({errno:"Invalid data"});
+ res.send({error:"Invalid data"});
}
} else {
- res.send({errno:"Invalid data"});
+ res.send({error:"Invalid data"});
}
}
@@ -3,7 +3,7 @@
*
* Returns:
- * - errno on failure
+ * - error on failure
* - on success we process with addNSEntriesToFile()
*
@@ -27,7 +27,7 @@ function continuethingsNS(validitycode,sh,res,gotit){
*
* Returns:
- * - errno on failure
+ * - error on failure
* - on success the string is processed for further validation to the
* function getNSvalidity()